@@ -1,5 +1,5 @@
 
-__version__ =  '0.1.1'
+__version__ = '0.1.3'
 
 from .csv_etl import CSVConverter
 from .rules import (
@@ -8,5 +8,6 @@ from .rules import (
     InputType,
     OutputType,
     load_rules_from_yaml,
-    SourceNotFound
+    SourceNotFound,
+    ConversionError
 )
